@@ -14,13 +14,18 @@
 
 from __future__ import print_function
 import os
+import sys
 import textwrap
 
 applianceSelf = os.environ['TOIL_APPLIANCE_SELF']
 sdistName = os.environ['_TOIL_SDIST_NAME']
 
+# Make sure to install packages into the pip for the version of Python we are
+# building for.
+pip = 'pip{}'.format(sys.version_info[0])
 
-dependencies = ' '.join(['libffi-dev',  # For client side encryption for 'azure' extra with PyNACL
+
+dependencies = ' '.join(['libffi-dev',  # For client side encryption for extras with PyNACL
                          'python3.6',
                          'python3.6-dev',
                          'python-dev',  # For installing Python packages with native code
@@ -34,7 +39,15 @@ dependencies = ' '.join(['libffi-dev',  # For client side encryption for 'azure'
                          'mesos=1.0.1-2.0.94.ubuntu1604',
                          "nodejs",  # CWL support for javascript expressions
                          'rsync',
-                         'screen'])
+                         'screen',
+                         'build-essential', # We need a build environment to build Singularity 3.
+                         'uuid-dev',
+                         'libgpgme11-dev',
+                         'libseccomp-dev',
+                         'pkg-config',
+                         'squashfs-tools',
+                         'cryptsetup',
+                         'git'])
 
 
 def heredoc(s):
@@ -48,7 +61,7 @@ motd = heredoc('''
     Run toil <workflow>.py --help to see all options for running your workflow.
     For more information see http://toil.readthedocs.io/en/latest/
 
-    Copyright (C) 2015-2018 Regents of the University of California
+    Copyright (C) 2015-2020 Regents of the University of California
 
     Version: {applianceSelf}
 
@@ -59,7 +72,7 @@ motd = ''.join(l + '\\n\\\n' for l in motd.splitlines())
 
 print(heredoc('''
     FROM ubuntu:16.04
-    
+
     RUN apt-get -y update --fix-missing && apt-get -y upgrade && apt-get -y install apt-transport-https ca-certificates software-properties-common && apt-get clean && rm -rf /var/lib/apt/lists/*
 
     RUN echo "deb http://repos.mesosphere.io/ubuntu/ xenial main" \
@@ -69,10 +82,30 @@ print(heredoc('''
         > /etc/apt/sources.list.d/nodesource.list \
         && apt-key adv --keyserver keyserver.ubuntu.com --recv 68576280
 
-    RUN add-apt-repository -y ppa:jonathonf/python-3.6
+    RUN add-apt-repository -y ppa:deadsnakes/ppa
     
-    RUN apt-get -y update --fix-missing && apt-get -y upgrade && apt-get -y install {dependencies} && apt-get clean && rm -rf /var/lib/apt/lists/*
+    RUN apt-get -y update --fix-missing && \
+        DEBIAN_FRONTEND=noninteractive apt-get -y upgrade && \
+        DEBIAN_FRONTEND=noninteractive apt-get -y install {dependencies} && \
+        apt-get clean && \
+        rm -rf /var/lib/apt/lists/*
 
+    RUN wget -q https://dl.google.com/go/go1.13.3.linux-amd64.tar.gz && \
+        tar xf go1.13.3.linux-amd64.tar.gz && \
+        rm go1.13.3.linux-amd64.tar.gz && \
+        mv go/bin/* /usr/bin/ && \
+        mv go /usr/local/
+        
+    RUN mkdir -p $(go env GOPATH)/src/github.com/sylabs && \
+        cd $(go env GOPATH)/src/github.com/sylabs && \
+        git clone https://github.com/sylabs/singularity.git && \
+        cd singularity && \
+        git checkout v3.4.2 && \
+        ./mconfig && \
+        cd ./builddir && \
+        make -j4 && \
+        make install
+    
     RUN mkdir /root/.ssh && \
         chmod 700 /root/.ssh
 
@@ -83,16 +116,16 @@ print(heredoc('''
     RUN chmod 777 /usr/bin/waitForKey.sh && chmod 777 /usr/bin/customDockerInit.sh
     
     # The stock pip is too old and can't install from sdist with extras
-    RUN pip install --upgrade pip==9.0.1
+    RUN {pip} install --upgrade pip==9.0.1
 
     # Default setuptools is too old
-    RUN pip install --upgrade setuptools==36.5.0
+    RUN {pip} install --upgrade setuptools==36.5.0
 
     # Include virtualenv, as it is still the recommended way to deploy pipelines
-    RUN pip install --upgrade virtualenv==15.0.3
+    RUN {pip} install --upgrade virtualenv==15.0.3
 
     # Install s3am (--never-download prevents silent upgrades to pip, wheel and setuptools)
-    RUN virtualenv --never-download /home/s3am \
+    RUN virtualenv --python python3 --never-download /home/s3am \
         && /home/s3am/bin/pip install s3am==2.0 \
         && ln -s /home/s3am/bin/s3am /usr/local/bin/
 
@@ -102,7 +135,7 @@ print(heredoc('''
          && chmod u+x /usr/local/bin/docker
 
     # Fix for Mesos interface dependency missing on ubuntu
-    RUN pip install protobuf==3.0.0
+    RUN {pip} install protobuf==3.0.0
 
     # Fix for https://issues.apache.org/jira/browse/MESOS-3793
     ENV MESOS_LAUNCHER=posix
@@ -124,7 +157,7 @@ print(heredoc('''
 
     # This component changes most frequently and keeping it last maximizes Docker cache hits.
     COPY {sdistName} .
-    RUN pip install {sdistName}[all]
+    RUN {pip} install {sdistName}[all]
     RUN rm {sdistName}
 
     # We intentionally inherit the default ENTRYPOINT and CMD from the base image, to the effect
