@@ -93,9 +93,11 @@ class LSFBatchSystem(AbstractGridEngineBatchSystem):
                          "{}".format(job))
             process = subprocess.Popen(args, stdout=subprocess.PIPE,
                                        stderr=subprocess.STDOUT)
+            output = process.stdout.read().decode('utf-8').replace("\n                     ", "")
+            process_output = output.split('\n')
             started = 0
-            for line in process.stdout:
-                if "Done successfully" in line:
+            for line in process_output:
+                if "Done successfully" in line or "Status <DONE>" in line:
                     logger.debug("bjobs detected job completed for job: "
                                  "{}".format(job))
                     return 0
@@ -103,7 +105,7 @@ class LSFBatchSystem(AbstractGridEngineBatchSystem):
                     logger.debug("bjobs detected job pending scheduling for "
                                  "job: {}".format(job))
                     return None
-                elif "PENDING REASONS" in line:
+                elif "PENDING REASONS" in line or "Status <PEND>" in line:
                     logger.debug("bjobs detected job pending for job: "
                                  "{}".format(job))
                     return None
@@ -117,9 +119,8 @@ class LSFBatchSystem(AbstractGridEngineBatchSystem):
                     logger.error("bjobs detected job failed for job: "
                                  "{}".format(job))
                     return 1
-                elif line.find("Started on ") > -1:
+                elif line.find("Started on ") > -1 or "Status <RUN>" in line:
                     started = 1
-
             if started == 1:
                 logger.debug("bjobs detected job started but not completed: "
                              "{}".format(job))
@@ -132,12 +133,14 @@ class LSFBatchSystem(AbstractGridEngineBatchSystem):
             args = ["bacct", "-l", str(job)]
             process = subprocess.Popen(args, stdout=subprocess.PIPE,
                                        stderr=subprocess.STDOUT)
-            for line in process.stdout:
-                if line.find("Completed <done>") > -1:
+            output = process.stdout.read().decode('utf-8')
+            process_output = output.split('\n')
+            for line in process_output:
+                if line.find("Completed <done>") > -1 or line.find("<DONE>") > -1:
                     logger.debug("Detected job completed for job: "
                                  "{}".format(job))
                     return 0
-                elif line.find("Completed <exit>") > -1:
+                elif line.find("Completed <exit>") > -1 or line.find("<EXIT>") > -1:
                     logger.error("Detected job failed for job: "
                                  "{}".format(job))
                     return 1
@@ -148,8 +151,7 @@ class LSFBatchSystem(AbstractGridEngineBatchSystem):
         """
         Implementation-specific helper methods
         """
-        @staticmethod
-        def prepareBsub(cpu, mem, jobID):
+        def prepareBsub(self, cpu, mem, jobID):
             """
             Make a bsub commandline to execute.
 
@@ -167,7 +169,8 @@ class LSFBatchSystem(AbstractGridEngineBatchSystem):
                     mem = old_div(float(mem), 1024**3)
                     mem_resource = parse_memory_resource(mem)
                     mem_limit = parse_memory_limit(mem)
-                bsubMem = ['-R', 'select[type==X86_64 && mem > {m}] '
+
+                bsubMem = ['-R', 'select[mem > {m}] '
                            'rusage[mem={m}]'.format(m=mem_resource),
                            '-M', str(mem_limit)]
             else:
@@ -213,15 +216,16 @@ class LSFBatchSystem(AbstractGridEngineBatchSystem):
         maxCPU = 0
         maxMEM = MemoryString("0")
         for line in p.stdout:
-                items = line.strip().split()
-                if len(items) < num_columns:
-                        RuntimeError("lshosts output has a varying number of "
-                                     "columns")
-                if items[cpu_index] != '-' and items[cpu_index] > maxCPU:
-                        maxCPU = items[cpu_index]
-                if (items[mem_index] != '-' and
-                        MemoryString(items[mem_index]) > maxMEM):
-                    maxMEM = MemoryString(items[mem_index])
+            split_items = line.strip().split()
+            items = [item.decode('utf-8') for item in split_items if isinstance(item, bytes)]
+            if len(items) < num_columns:
+                RuntimeError("lshosts output has a varying number of "
+                             "columns")
+            if items[cpu_index] != '-' and int(items[cpu_index]) > int(maxCPU):
+                maxCPU = items[cpu_index]
+            if (items[mem_index] != '-' and
+                MemoryString(items[mem_index]) > maxMEM):
+                maxMEM = MemoryString(items[mem_index])
 
         if maxCPU is 0 or maxMEM is 0:
                 RuntimeError("lshosts returns null ncpus or maxmem info")
